/*
 * Pan - A Newsreader for X
 * Copyright (C) 1999, 2000, 2001  Pan Development Team <pan@rebelbase.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * 
 */

#ifndef __TASK_GROUP_COUNT__H__
#define __TASK_GROUP_COUNT__H__

#include <pan/base/group.h>
#include <pan/task.h>

#define TASK_GROUP_COUNT(obj) ((TaskGroupCount*)(obj))

typedef struct
{
	/* parent class */
	Task           task;

	/* private, passed in ctor */
	GPtrArray    * groups;
}
TaskGroupCount;

/**
***  PUBLIC
**/

PanObject*   task_group_count_new   (Group      ** groups,
                                     guint         qty);


#endif /* __TASK_BODY__H__ */
